"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.appDeployComponent = exports.appDeployLinuxAndRemoteDevice = void 0;
const logSymbols = require("log-symbols");
const alwayscli_1 = require("@alwaysai/alwayscli");
const target_json_file_1 = require("../../core/app/target-json-file");
const app_check_component_1 = require("./app-check-component");
const paths_1 = require("../../paths");
const docker_1 = require("../docker");
const util_1 = require("../../util");
const project_1 = require("../../core/project");
const docker_compose_cmd_1 = require("../../util/docker/docker-compose-cmd");
const app_1 = require("../../core/app");
async function appDeployLinuxAndRemoteDevice(props) {
    const { yes, generateDockerCompose, logs, stop, targetJson, targetConfig } = props;
    const targetHostSpawner = targetJson.readHostSpawner();
    const { targetHardware } = targetConfig;
    if (logs) {
        await (0, docker_compose_cmd_1.dockerComposeLogs)(targetHostSpawner);
        return;
    }
    if (stop) {
        await (0, docker_compose_cmd_1.dockerComposeDown)(targetHostSpawner);
        (0, util_1.echo)(`${logSymbols.success} App stopped.`);
        return;
    }
    await (0, docker_1.checkForDockerComposeComponent)(targetHostSpawner);
    await (0, docker_1.writeStandaloneDockerfileComponent)();
    if (targetConfig.targetProtocol === 'ssh+docker:') {
        await (0, util_1.copyFile)((0, util_1.JsSpawner)(), targetHostSpawner, paths_1.DOCKERFILE_STANDALONE);
    }
    const found = await (0, docker_1.findOrWriteDockerComposeFileComponent)({
        yes,
        cmd: await (0, app_1.getDockerComposeCmdForApp)({ targetHardware }),
    });
    if (found) {
        await (0, app_1.updateDockerComposeTargetHw)({ targetHardware });
    }
    if (generateDockerCompose) {
        return;
    }
    if (targetConfig.targetProtocol === 'ssh+docker:') {
        await (0, util_1.copyFile)((0, util_1.JsSpawner)(), targetHostSpawner, paths_1.DOCKER_COMPOSE_FILE);
    }
    await (0, docker_compose_cmd_1.dockerComposeBuild)(targetHostSpawner);
    await (0, docker_compose_cmd_1.dockerComposeUp)(targetHostSpawner);
    (0, util_1.echo)(`${logSymbols.success} App deployed.`);
}
exports.appDeployLinuxAndRemoteDevice = appDeployLinuxAndRemoteDevice;
async function appDeployComponent(props) {
    const { yes, generateDockerCompose, logs, stop } = props;
    await (0, app_check_component_1.appCheckComponent)();
    await (0, project_1.requirePaidPlan)();
    const targetJson = (0, target_json_file_1.TargetJsonFile)();
    const targetConfig = targetJson.read();
    switch (targetConfig.targetProtocol) {
        case 'docker:':
        case 'ssh+docker:': {
            await appDeployLinuxAndRemoteDevice({
                yes,
                generateDockerCompose,
                logs,
                stop,
                targetJson,
                targetConfig,
            });
            break;
        }
        default: {
            throw new alwayscli_1.CliTerseError(`Deploy is not supported for native installations.`);
        }
    }
}
exports.appDeployComponent = appDeployComponent;
//# sourceMappingURL=app-deploy-component.js.map