"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.targetJsonComponent = void 0;
const alwayscli_1 = require("@alwaysai/alwayscli");
const destination_prompt_component_1 = require("./destination-prompt-component");
const target_path_prompt_component_1 = require("./target-path-prompt-component");
const target_protocol_prompt_component_1 = require("./target-protocol-prompt-component");
const write_target_json_file_component_1 = require("./write-target-json-file-component");
const constants_1 = require("../../../constants");
const device_1 = require("../../device");
const docker_1 = require("../../docker");
const util_1 = require("../../../util");
const app_1 = require("../../../core/app");
const project_1 = require("../../../core/project");
const general_1 = require("../../general");
async function targetJsonComponent(props) {
    const { yes } = props;
    const currentTargetJson = (0, app_1.TargetJsonFile)();
    const currentTargetProtocol = currentTargetJson.readTargetProtocolSafe();
    let targetProtocol;
    if (yes) {
        targetProtocol = props.targetProtocol || currentTargetProtocol;
        if (!targetProtocol) {
            throw new alwayscli_1.CliUsageError((0, util_1.RequiredWithYesMessage)('protocol', undefined));
        }
        if (targetProtocol === 'native:' || targetProtocol === 'docker:') {
            if (!(await (0, destination_prompt_component_1.checkProcessorBrand)())) {
                throw new alwayscli_1.CliUsageError('edgeIQ is not supported on devices with Atom/Celeron processors.');
            }
        }
    }
    else if (!props.targetProtocol) {
        targetProtocol = await (0, target_protocol_prompt_component_1.targetProtocolPromptComponent)({
            prevTargetProtocol: currentTargetProtocol,
        });
    }
    else {
        targetProtocol = props.targetProtocol;
    }
    switch (targetProtocol) {
        case 'native:': {
            (0, write_target_json_file_component_1.writeTargetJsonFileComponent)({
                targetProtocol,
            });
            break;
        }
        case 'docker:': {
            await (0, docker_1.checkForDockerComponent)();
            const targetHardware = props.targetHardware || (await (0, app_1.getTargetHardwareType)({}));
            (0, write_target_json_file_component_1.writeTargetJsonFileComponent)({
                targetProtocol,
                dockerImageId: constants_1.DOCKER_IMAGE_ID_INITIAL_VALUE,
                targetHardware,
            });
            break;
        }
        case 'ssh+docker:': {
            await (0, general_1.findOrWritePrivateKeyFileComponent)({ yes });
            const projectJsonFile = (0, project_1.ProjectJsonFile)();
            const projectConfig = projectJsonFile.read().project;
            if (!projectConfig) {
                throw new alwayscli_1.CliTerseError(`App must have a project associated with it. Run '${constants_1.ALWAYSAI_CLI_EXECUTABLE_NAME} app configure' to select a project.`);
            }
            const projectId = projectConfig.id;
            const device = await (0, device_1.deviceSelectComponent)({
                yes,
                deviceId: props.deviceId,
            });
            const targetHostname = await (0, device_1.getTargetHostnameComponent)({
                yes,
                device,
                targetHostname: props.targetHostname,
            });
            if (targetHostname === undefined) {
                throw new alwayscli_1.CliTerseError('Cannot access selected device! The device hostname is unknown.');
            }
            await (0, device_1.deviceCheckAndUpdateComponent)({ yes, targetHostname, device });
            await (0, project_1.addDeviceToProject)({ device, projectId });
            await (0, docker_1.checkForDockerComponent)({ targetHostname });
            let targetPath = props.targetPath ||
                currentTargetJson.readFieldSafe({ name: 'targetPath' }) ||
                (0, app_1.TargetPathDefaultValue)();
            if (!yes) {
                targetPath = await (0, target_path_prompt_component_1.targetPathPromptComponent)({
                    targetHostname,
                    targetPath,
                });
            }
            const targetHardware = props.targetHardware || (await (0, app_1.getTargetHardwareType)({ targetHostname }));
            (0, app_1.TargetJsonFile)().write({
                targetProtocol,
                targetHostname,
                targetPath,
                dockerImageId: constants_1.DOCKER_IMAGE_ID_INITIAL_VALUE,
                targetHardware,
                deviceId: device.uuid,
            });
            break;
        }
        default:
            throw new Error('Unsupported protocol');
    }
}
exports.targetJsonComponent = targetJsonComponent;
//# sourceMappingURL=target-json-component.js.map