"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const alwayscli_1 = require("@alwaysai/alwayscli");
const run_and_catch_1 = require("@carnesen/run-and-catch");
const app_1 = require("../../../core/app");
const target_json_component_1 = require("./target-json-component");
const target_path_prompt_component_1 = require("./target-path-prompt-component");
const target_protocol_prompt_component_1 = require("./target-protocol-prompt-component");
const constants_1 = require("../../../constants");
const device_1 = require("../../device");
const docker_1 = require("../../docker");
const project_1 = require("../../../core/project");
const general_1 = require("../../general");
jest.mock('../../../core/app');
const mockTargetJsonFileExists = jest.fn().mockReturnValue(false);
const mockTargetJsonFileReadTargetProtocolSafe = jest.fn();
const mockTargetJsonFileReadFieldSafe = jest.fn().mockReturnValue(undefined);
const mockTargetJsonFileWrite = jest.fn();
jest.mocked(app_1.TargetJsonFile).mockReturnValue({
    exists: mockTargetJsonFileExists,
    readTargetProtocolSafe: mockTargetJsonFileReadTargetProtocolSafe,
    readFieldSafe: mockTargetJsonFileReadFieldSafe,
    write: mockTargetJsonFileWrite,
});
jest.mock('../../../core/project');
const projectId = '17';
const mockProjectJsonFileRead = jest.fn().mockReturnValue({
    project: { id: projectId },
});
jest.mocked(project_1.ProjectJsonFile).mockReturnValue({
    read: mockProjectJsonFileRead,
});
jest.mock('./target-protocol-prompt-component');
jest.mock('../../docker');
jest.mock('../../device');
jest.mock('../../general');
jest.mock('./target-path-prompt-component');
describe(target_json_component_1.targetJsonComponent.name, () => {
    afterEach(() => {
        jest.clearAllMocks();
    });
    jest.setTimeout(30000);
    it('--yes without target protocol', async () => {
        const exception = await (0, run_and_catch_1.runAndCatch)(target_json_component_1.targetJsonComponent, {
            yes: true,
        });
        expect(exception.code).toBe(alwayscli_1.CLI_USAGE_ERROR);
    });
    describe('native', () => {
        it('--yes via command line', async () => {
            await (0, target_json_component_1.targetJsonComponent)({
                yes: true,
                targetProtocol: 'native:',
            });
            expect(mockTargetJsonFileWrite).toBeCalledTimes(1);
            expect(mockTargetJsonFileWrite).toBeCalledWith({
                targetProtocol: 'native:',
            });
        });
        it('--yes via config file', async () => {
            mockTargetJsonFileExists.mockReturnValue(true);
            mockTargetJsonFileReadTargetProtocolSafe.mockReturnValue('native:');
            await (0, target_json_component_1.targetJsonComponent)({
                yes: true,
            });
            expect(mockTargetJsonFileWrite).toBeCalledTimes(1);
            expect(mockTargetJsonFileWrite).toBeCalledWith({
                targetProtocol: 'native:',
            });
        });
        it('native via prompt', async () => {
            // Test with previous value in config
            mockTargetJsonFileExists.mockReturnValue(true);
            mockTargetJsonFileReadTargetProtocolSafe.mockReturnValue('docker:');
            jest.mocked(target_protocol_prompt_component_1.targetProtocolPromptComponent).mockResolvedValue('native:');
            await (0, target_json_component_1.targetJsonComponent)({
                yes: false,
            });
            expect(jest.mocked(target_protocol_prompt_component_1.targetProtocolPromptComponent)).toBeCalledTimes(1);
            expect(jest.mocked(target_protocol_prompt_component_1.targetProtocolPromptComponent)).toBeCalledWith({
                prevTargetProtocol: 'docker:',
            });
            expect(mockTargetJsonFileWrite).toBeCalledTimes(1);
            expect(mockTargetJsonFileWrite).toBeCalledWith({
                targetProtocol: 'native:',
            });
        });
    });
    describe('docker', () => {
        it('--yes via command line', async () => {
            mockTargetJsonFileExists.mockReturnValue(false);
            const targetHardware = 'jetson-jp4.6';
            jest.mocked(app_1.getTargetHardwareType).mockResolvedValue(targetHardware);
            await (0, target_json_component_1.targetJsonComponent)({
                yes: true,
                targetProtocol: 'docker:',
            });
            expect(jest.mocked(docker_1.checkForDockerComponent)).toBeCalledTimes(1);
            expect(jest.mocked(app_1.getTargetHardwareType)).toBeCalledTimes(1);
            expect(jest.mocked(app_1.getTargetHardwareType)).toBeCalledWith({});
            expect(mockTargetJsonFileWrite).toBeCalledTimes(1);
            expect(mockTargetJsonFileWrite).toBeCalledWith({
                targetProtocol: 'docker:',
                dockerImageId: constants_1.DOCKER_IMAGE_ID_INITIAL_VALUE,
                targetHardware,
            });
        });
        it('--yes targetHardware via command line', async () => {
            mockTargetJsonFileExists.mockReturnValue(false);
            const targetHardware = 'jetson-jp4.6';
            await (0, target_json_component_1.targetJsonComponent)({
                yes: true,
                targetProtocol: 'docker:',
                targetHardware,
            });
            expect(jest.mocked(docker_1.checkForDockerComponent)).toBeCalledTimes(1);
            expect(jest.mocked(app_1.getTargetHardwareType)).toBeCalledTimes(0);
            expect(mockTargetJsonFileWrite).toBeCalledTimes(1);
            expect(mockTargetJsonFileWrite).toBeCalledWith({
                targetProtocol: 'docker:',
                dockerImageId: constants_1.DOCKER_IMAGE_ID_INITIAL_VALUE,
                targetHardware,
            });
        });
    });
    describe('ssh+docker', () => {
        it('--yes targetPath via command line', async () => {
            mockTargetJsonFileExists.mockReturnValue(false);
            const device = {
                uuid: 'C3P0',
                host_name: 'threepio',
                hardware_ids: '1234',
            };
            jest.mocked(device_1.deviceSelectComponent).mockResolvedValue(device);
            const targetHardware = 'amd64';
            jest.mocked(device_1.getTargetHostnameComponent).mockResolvedValue(device.host_name);
            jest.mocked(app_1.getTargetHardwareType).mockResolvedValue(targetHardware);
            const targetPath = 'tatooine';
            await (0, target_json_component_1.targetJsonComponent)({
                yes: true,
                targetProtocol: 'ssh+docker:',
                targetPath,
            });
            expect(jest.mocked(general_1.findOrWritePrivateKeyFileComponent)).toBeCalledTimes(1);
            expect(jest.mocked(general_1.findOrWritePrivateKeyFileComponent)).toBeCalledWith({
                yes: true,
            });
            expect(mockProjectJsonFileRead).toBeCalledTimes(1);
            expect(jest.mocked(device_1.deviceSelectComponent)).toBeCalledTimes(1);
            expect(jest.mocked(device_1.deviceSelectComponent)).toBeCalledWith({
                yes: true,
                deviceId: undefined,
            });
            expect(jest.mocked(device_1.getTargetHostnameComponent)).toBeCalledTimes(1);
            expect(jest.mocked(device_1.getTargetHostnameComponent)).toBeCalledWith({
                yes: true,
                device,
            });
            expect(jest.mocked(docker_1.checkForDockerComponent)).toBeCalledTimes(1);
            expect(jest.mocked(docker_1.checkForDockerComponent)).toBeCalledWith({
                targetHostname: device.host_name,
            });
            expect(jest.mocked(target_path_prompt_component_1.targetPathPromptComponent)).toBeCalledTimes(0);
            expect(jest.mocked(app_1.getTargetHardwareType)).toBeCalledTimes(1);
            expect(jest.mocked(app_1.getTargetHardwareType)).toBeCalledWith({
                targetHostname: device.host_name,
            });
            expect(mockTargetJsonFileWrite).toBeCalledTimes(1);
            expect(mockTargetJsonFileWrite).toBeCalledWith({
                targetProtocol: 'ssh+docker:',
                targetHostname: device.host_name,
                targetPath,
                dockerImageId: constants_1.DOCKER_IMAGE_ID_INITIAL_VALUE,
                targetHardware,
                deviceId: device.uuid,
            });
        });
        it('--yes targetHardware and targetPath via command line', async () => {
            mockTargetJsonFileExists.mockReturnValue(false);
            const device = {
                uuid: 'C3P0',
                host_name: 'threepio',
                hardware_ids: '1234',
            };
            jest.mocked(device_1.deviceSelectComponent).mockResolvedValue(device);
            jest.mocked(device_1.getTargetHostnameComponent).mockResolvedValue(device.host_name);
            const targetHardware = 'amd64';
            const targetPath = 'tatooine';
            await (0, target_json_component_1.targetJsonComponent)({
                yes: true,
                targetProtocol: 'ssh+docker:',
                targetHardware,
                targetPath,
            });
            expect(jest.mocked(general_1.findOrWritePrivateKeyFileComponent)).toBeCalledTimes(1);
            expect(jest.mocked(general_1.findOrWritePrivateKeyFileComponent)).toBeCalledWith({
                yes: true,
            });
            expect(mockProjectJsonFileRead).toBeCalledTimes(1);
            expect(jest.mocked(device_1.deviceSelectComponent)).toBeCalledTimes(1);
            expect(jest.mocked(device_1.deviceSelectComponent)).toBeCalledWith({
                yes: true,
                deviceId: undefined,
            });
            expect(jest.mocked(device_1.getTargetHostnameComponent)).toBeCalledTimes(1);
            expect(jest.mocked(device_1.getTargetHostnameComponent)).toBeCalledWith({
                yes: true,
                device,
            });
            expect(jest.mocked(docker_1.checkForDockerComponent)).toBeCalledTimes(1);
            expect(jest.mocked(docker_1.checkForDockerComponent)).toBeCalledWith({
                targetHostname: device.host_name,
            });
            expect(jest.mocked(target_path_prompt_component_1.targetPathPromptComponent)).toBeCalledTimes(0);
            expect(jest.mocked(app_1.getTargetHardwareType)).toBeCalledTimes(0);
            expect(mockTargetJsonFileWrite).toBeCalledTimes(1);
            expect(mockTargetJsonFileWrite).toBeCalledWith({
                targetProtocol: 'ssh+docker:',
                targetHostname: device.host_name,
                targetPath,
                dockerImageId: constants_1.DOCKER_IMAGE_ID_INITIAL_VALUE,
                targetHardware,
                deviceId: device.uuid,
            });
        });
        it('target path via prompt', async () => {
            mockTargetJsonFileExists.mockReturnValue(false);
            const device = {
                uuid: 'C3P0',
                host_name: 'threepio',
                hardware_ids: '1234',
            };
            jest.mocked(device_1.deviceSelectComponent).mockResolvedValue(device);
            jest.mocked(device_1.getTargetHostnameComponent).mockResolvedValue(device.host_name);
            const targetHardware = 'aarch64';
            jest.mocked(app_1.getTargetHardwareType).mockResolvedValue(targetHardware);
            const targetPath = 'tatooine';
            jest.mocked(target_path_prompt_component_1.targetPathPromptComponent).mockResolvedValue(targetPath);
            const targetHostname = 'deetoo';
            await (0, target_json_component_1.targetJsonComponent)({
                yes: false,
                targetProtocol: 'ssh+docker:',
                targetHostname,
            });
            expect(jest.mocked(general_1.findOrWritePrivateKeyFileComponent)).toBeCalledTimes(1);
            expect(jest.mocked(general_1.findOrWritePrivateKeyFileComponent)).toBeCalledWith({
                yes: false,
            });
            expect(mockProjectJsonFileRead).toBeCalledTimes(1);
            expect(jest.mocked(device_1.deviceSelectComponent)).toBeCalledTimes(1);
            expect(jest.mocked(device_1.deviceSelectComponent)).toBeCalledWith({
                yes: false,
                deviceId: undefined,
            });
            expect(jest.mocked(device_1.getTargetHostnameComponent)).toBeCalledTimes(1);
            expect(jest.mocked(device_1.getTargetHostnameComponent)).toBeCalledWith({
                yes: false,
                device,
                targetHostname,
            });
            expect(jest.mocked(docker_1.checkForDockerComponent)).toBeCalledTimes(1);
            expect(jest.mocked(docker_1.checkForDockerComponent)).toBeCalledWith({
                targetHostname: device.host_name,
            });
            expect(mockTargetJsonFileReadFieldSafe).toBeCalledTimes(1);
            expect(mockTargetJsonFileReadFieldSafe).toBeCalledWith({
                name: 'targetPath',
            });
            expect(jest.mocked(target_path_prompt_component_1.targetPathPromptComponent)).toBeCalledTimes(1);
            expect(jest.mocked(target_path_prompt_component_1.targetPathPromptComponent)).toBeCalledWith({
                targetHostname: device.host_name,
                targetPath: (0, app_1.TargetPathDefaultValue)(),
            });
            expect(jest.mocked(app_1.getTargetHardwareType)).toBeCalledTimes(1);
            expect(jest.mocked(app_1.getTargetHardwareType)).toBeCalledWith({
                targetHostname: device.host_name,
            });
            expect(mockTargetJsonFileWrite).toBeCalledTimes(1);
            expect(mockTargetJsonFileWrite).toBeCalledWith({
                targetProtocol: 'ssh+docker:',
                targetHostname: device.host_name,
                targetPath,
                dockerImageId: constants_1.DOCKER_IMAGE_ID_INITIAL_VALUE,
                targetHardware,
                deviceId: device.uuid,
            });
        });
    });
});
//# sourceMappingURL=target-json-component.test.js.map