"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deviceCheckAndUpdateComponent = void 0;
const app_1 = require("../../core/app");
const infrastructure_1 = require("../../infrastructure");
const alwayscli_1 = require("@alwaysai/alwayscli");
const util_1 = require("../../util");
const device_1 = require("../../core/device");
const paths_1 = require("../../paths");
async function deviceCheckAndUpdateComponent(props) {
    const { targetHostname, device } = props;
    const spawner = (0, util_1.SshSpawner)({
        targetHostname,
        targetPath: paths_1.REMOTE_AAI_CFG_DIR_LINUX,
    });
    await (0, util_1.runWithSpinner)(async () => {
        const hardwareId = await (0, app_1.getTargetHardwareUuid)(spawner);
        if (hardwareId !== device.hardware_ids) {
            throw new alwayscli_1.CliTerseError(`Target device does not match the selected device!`);
        }
        try {
            await (0, device_1.writeOrValidateDeviceCfgFile)({ spawner, deviceUuid: device.uuid });
        }
        catch (e) {
            throw new alwayscli_1.CliTerseError(e.message);
        }
    }, [], 'Check device configuration');
    if (device.mode === 'development') {
        // Development tokens don't expire, and therefore don't need to be refreshed.
        // Additionally, we don't want to overwrite existing tokens on a provisioned
        // production device.
        await (0, util_1.runWithSpinner)(async () => {
            const { accessToken, refreshToken, idToken } = await (0, infrastructure_1.refreshDevice)(device.uuid);
            const tokens = {
                deviceId: device.uuid,
                accessToken,
                refreshToken,
                idToken,
            };
            await (0, device_1.writeTokens)({ spawner, tokens });
        }, [], 'Write tokens to device');
    }
}
exports.deviceCheckAndUpdateComponent = deviceCheckAndUpdateComponent;
//# sourceMappingURL=device-check-and-update-component.js.map