"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const alwayscli_1 = require("@alwaysai/alwayscli");
const run_and_catch_1 = require("@carnesen/run-and-catch");
const device_add_component_1 = require("./device-add-component");
const device_select_component_1 = require("./device-select-component");
const util_1 = require("../../util");
const infrastructure_1 = require("../../infrastructure");
jest.mock('../../infrastructure');
const mockGetUserDevices = jest.fn().mockResolvedValue({});
const mockCheckTeamLimits = jest.fn().mockResolvedValue({});
const mockCheckTeamsUserIsOwner = jest.fn().mockResolvedValue({});
jest.mocked(infrastructure_1.CliRpcClient).mockReturnValue({
    getUserDevices: mockGetUserDevices,
    checkTeamLimits: mockCheckTeamLimits,
    listTeamsUserIsOwner: mockCheckTeamsUserIsOwner,
});
const mockGetInfo = jest.fn().mockResolvedValue({});
jest.mocked(infrastructure_1.CliAuthenticationClient).mockReturnValue({
    getInfo: mockGetInfo,
});
jest.mock('../../util/prompt-for-input');
jest.mock('./device-add-component');
function createDevice(props) {
    const { friendlyName, hwId, mode = 'production' } = props;
    const id = Math.random();
    return {
        owner: '',
        friendly_name: friendlyName,
        host_name: `${friendlyName}.local`,
        device_user_name: '',
        description: '',
        hardware_ids: hwId || '1234',
        device_hash: '',
        id,
        uuid: `${id}`,
        mode,
        cognito_device_key: '',
        deleted: false,
        created_at: '',
        updated_at: '',
    };
}
function setupMocksForDeviceSelectComponentPrompt(props) {
    const { username, userDevices, selectedDevice, targetDevice = 'new' } = props;
    mockGetInfo.mockResolvedValue({ username });
    mockGetUserDevices.mockResolvedValue(userDevices);
    jest.mocked(util_1.promptForInput).mockResolvedValue({
        targetDevice,
    });
    if (targetDevice === 'new') {
        jest.mocked(device_add_component_1.deviceAddComponent).mockResolvedValue(selectedDevice);
    }
}
function checkMocksForDeviceSelectComponentPrompt({ isNew }) {
    expect(mockGetInfo).toBeCalledTimes(1);
    expect(mockGetUserDevices).toBeCalledTimes(1);
    expect(jest.mocked(util_1.promptForInput)).toBeCalledTimes(1);
    if (isNew) {
        expect(jest.mocked(device_add_component_1.deviceAddComponent)).toBeCalledTimes(1);
    }
    else {
        expect(jest.mocked(device_add_component_1.deviceAddComponent)).toBeCalledTimes(0);
    }
}
describe(device_select_component_1.deviceSelectComponent.name, () => {
    afterEach(() => {
        jest.clearAllMocks();
    });
    jest.setTimeout(30000);
    describe('--yes', () => {
        test('without deviceId arg', async () => {
            const exception = await (0, run_and_catch_1.runAndCatch)(device_select_component_1.deviceSelectComponent, {
                yes: true,
            });
            expect(exception.code).toBe(alwayscli_1.CLI_USAGE_ERROR);
        });
        it('with deviceId arg', async () => {
            const device = createDevice({ friendlyName: 'mainsail' });
            jest.mocked(infrastructure_1.getDeviceByUuid).mockResolvedValue(device);
            const out = await (0, device_select_component_1.deviceSelectComponent)({
                yes: true,
                deviceId: device.uuid,
            });
            expect(jest.mocked(infrastructure_1.getDeviceByUuid)).toBeCalledTimes(1);
            expect(jest.mocked(infrastructure_1.getDeviceByUuid).mock.calls[0][0]).toEqual({
                uuid: device.uuid,
            });
            expect(out).toBe(device);
        });
    });
    describe('prompt for device', () => {
        test('select existing device successfully', async () => {
            const username = 'Chewbacca';
            const hwId = '5678';
            const device0 = createDevice({ friendlyName: 'stormjib', hwId: '1234' });
            const device1 = createDevice({ friendlyName: 'windseeker', hwId });
            const devices = [device0, device1];
            setupMocksForDeviceSelectComponentPrompt({
                username,
                userDevices: devices,
                selectedDevice: device1,
                targetDevice: 1,
            });
            const out = await (0, device_select_component_1.deviceSelectComponent)({
                yes: false,
            });
            checkMocksForDeviceSelectComponentPrompt({
                isNew: false,
            });
            expect(out).toBe(device1);
        });
    });
});
//# sourceMappingURL=device-select-component.test.js.map