"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeOrValidateDeviceCfgFile = void 0;
const paths_1 = require("../../paths");
const infrastructure_1 = require("../../infrastructure");
const device_json_file_1 = require("./device-json-file");
async function writeOrValidateDeviceCfgFile(args) {
    const { spawner, deviceUuid } = args;
    if (!(await spawner.exists(paths_1.DEVICE_CONFIG_FILE_NAME))) {
        const contents = { systemId: (0, infrastructure_1.getSystemId)(), deviceUuid };
        await spawner.mkdirp();
        await spawner.writeFile(paths_1.DEVICE_CONFIG_FILE_NAME, JSON.stringify(contents, null, 2));
        return;
    }
    const origContents = await spawner.readFile(paths_1.DEVICE_CONFIG_FILE_NAME);
    const origParsed = JSON.parse(origContents);
    if (!(0, device_json_file_1.validateDeviceConfig)(origParsed)) {
        throw new Error(`Invalid device config contents: ${JSON.stringify(device_json_file_1.validateDeviceConfig.errors, null, 2)}`);
    }
    if (origParsed.deviceUuid !== deviceUuid) {
        throw new Error("Target device doesn't match selected device!");
    }
}
exports.writeOrValidateDeviceCfgFile = writeOrValidateDeviceCfgFile;
//# sourceMappingURL=write-or-validate-device-cfg-file.js.map