"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const write_or_validate_device_cfg_file_1 = require("./write-or-validate-device-cfg-file");
const run_and_catch_1 = require("@carnesen/run-and-catch");
function getSpawner(args) {
    const { fileExists, readFileOut } = args;
    const spawner = {
        exists: jest.fn().mockResolvedValue(fileExists === true ? true : false),
        mkdirp: jest.fn().mockResolvedValue({}),
        writeFile: jest.fn().mockResolvedValue({}),
        readFile: jest.fn().mockResolvedValue(readFileOut),
    };
    return spawner;
}
describe('Test writeOrValidateDeviceCfgFile', () => {
    test("file doesn't exist", async () => {
        const spawner = getSpawner({});
        const deviceUuid = '1234';
        await (0, write_or_validate_device_cfg_file_1.writeOrValidateDeviceCfgFile)({ spawner, deviceUuid });
        expect(spawner.exists).toBeCalled();
        expect(spawner.mkdirp).toBeCalled();
        expect(spawner.writeFile).toBeCalled();
    });
    test('File exists but invalid json', async () => {
        const readFileOut = 'not valid json';
        const spawner = getSpawner({ fileExists: true, readFileOut });
        const deviceUuid = '1234';
        await (0, run_and_catch_1.runAndCatch)(write_or_validate_device_cfg_file_1.writeOrValidateDeviceCfgFile, { spawner, deviceUuid });
        expect(spawner.exists).toBeCalled();
        expect(spawner.readFile).toBeCalled();
    });
    test('File exists but invalid contents', async () => {
        const readFileOut = JSON.stringify({
            notAField: 'not a field',
        });
        const spawner = getSpawner({ fileExists: true, readFileOut });
        const deviceUuid = '1234';
        await (0, run_and_catch_1.runAndCatch)(write_or_validate_device_cfg_file_1.writeOrValidateDeviceCfgFile, { spawner, deviceUuid });
        expect(spawner.exists).toBeCalled();
        expect(spawner.readFile).toBeCalled();
    });
    test('File exists with mismatching device UUID', async () => {
        const readFileOut = JSON.stringify({
            systemId: 'production',
            deviceUuid: '5678',
        });
        const spawner = getSpawner({ fileExists: true, readFileOut });
        const deviceUuid = '1234';
        await (0, run_and_catch_1.runAndCatch)(write_or_validate_device_cfg_file_1.writeOrValidateDeviceCfgFile, { spawner, deviceUuid });
        expect(spawner.exists).toBeCalled();
        expect(spawner.readFile).toBeCalled();
    });
    test('File exists with matching device UUID', async () => {
        const readFileOut = JSON.stringify({
            systemId: 'production',
            deviceUuid: '1234',
        });
        const spawner = getSpawner({ fileExists: true, readFileOut });
        const deviceUuid = '1234';
        await (0, write_or_validate_device_cfg_file_1.writeOrValidateDeviceCfgFile)({ spawner, deviceUuid });
        expect(spawner.exists).toBeCalled();
        expect(spawner.readFile).toBeCalled();
    });
});
//# sourceMappingURL=write-or-validate-device-cfg-file.test.js.map