"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.removeDockerImages = exports.dockerIsInstalledAndRunning = exports.getAllLegacyTrainingImages = void 0;
const util_1 = require("../../util");
async function spawnProcess(exe, args) {
    const spawner = (0, util_1.JsSpawner)();
    return await spawner.run({ exe, args });
}
function parseImagesStdOutToArray(images) {
    return images.trim().split(/\r?\n/);
}
async function getAllLegacyTrainingImages() {
    const resProd = await spawnProcess('docker', ['images', '-q', 'alwaysai/train']);
    const resQa = await spawnProcess('docker', ['images', '-q', 'alwaysai/train-qa']);
    const resDev = await spawnProcess('docker', ['images', '-q', 'alwaysai/training-dev']);
    const imageIds = parseImagesStdOutToArray(`${resProd}\n${resQa}\n${resDev}`);
    return imageIds.length === 1 && imageIds[0] === '' ? [] : imageIds;
}
exports.getAllLegacyTrainingImages = getAllLegacyTrainingImages;
async function dockerIsInstalledAndRunning() {
    try {
        await spawnProcess('docker', ['container', 'ls']);
        return true;
    }
    catch (_a) {
        return false;
    }
}
exports.dockerIsInstalledAndRunning = dockerIsInstalledAndRunning;
async function removeDockerImages(images) {
    await spawnProcess('docker', ['rmi', '-f', ...images]);
}
exports.removeDockerImages = removeDockerImages;
//# sourceMappingURL=remove-legacy-training-images.js.map