"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSystemId = exports.setSystemId = void 0;
const path_1 = require("path");
const t = require("io-ts");
const config_nodejs_1 = require("@alwaysai/config-nodejs");
const alwayscli_1 = require("@alwaysai/alwayscli");
const environment_1 = require("../environment");
const constants_1 = require("../constants");
const paths_1 = require("../paths");
const props = {
    systemId: t.keyof(constants_1.SystemId),
};
const codec = t.partial(props);
const CLI_JSON_FILE_NAME = 'alwaysai.cli.json';
const path = (0, path_1.join)(paths_1.LOCAL_AAI_CFG_DIR, CLI_JSON_FILE_NAME);
const cliJsonFile = (0, config_nodejs_1.ConfigFile)({
    path,
    codec,
    ENOENT: {
        code: alwayscli_1.CLI_TERSE_ERROR,
        message: `File not found ${CLI_JSON_FILE_NAME}. Run command "${constants_1.ALWAYSAI_CLI_EXECUTABLE_NAME} config set" to set configuration values.`,
    },
    EACCES: {
        code: alwayscli_1.CLI_TERSE_ERROR,
        message: `Please ensure the permissions on ${paths_1.LOCAL_AAI_CFG_DIR} include read and write access for the current user.`,
    },
    initialValue: {},
});
function setSystemId(systemId) {
    return cliJsonFile.update((json) => {
        json.systemId = systemId;
    });
}
exports.setSystemId = setSystemId;
function getSystemId() {
    if (environment_1.ALWAYSAI_SYSTEM_ID) {
        // When the env var is set return the overridden value without updating the config file.
        // This prevents one-off commands from having side effects.
        if (Object.keys(constants_1.SystemId).includes(environment_1.ALWAYSAI_SYSTEM_ID)) {
            return environment_1.ALWAYSAI_SYSTEM_ID;
        }
        throw new Error(`Invalid ALWAYSAI_SYSTEM_ID: ${environment_1.ALWAYSAI_SYSTEM_ID}`);
    }
    const maybeConfig = cliJsonFile.readIfExists();
    if (!maybeConfig || !maybeConfig.systemId) {
        setSystemId('production');
    }
    const systemId = maybeConfig && maybeConfig.systemId ? maybeConfig.systemId : 'production';
    return systemId;
}
exports.getSystemId = getSystemId;
//# sourceMappingURL=system-id.js.map