"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.serviceEndpointBuilder = exports.getBaseURL = exports.getRemoteDeploymentURL = exports.getRestURL = void 0;
const alwayscli_1 = require("@alwaysai/alwayscli");
const system_id_1 = require("./system-id");
function getRestURL() {
    let restUrl = '';
    switch ((0, system_id_1.getSystemId)()) {
        case 'local':
        case 'development':
            restUrl = 'https://lhm86739h4.execute-api.us-west-2.amazonaws.com/dev';
            break;
        case 'qa':
            restUrl = 'https://2fz3afqai8.execute-api.us-west-2.amazonaws.com/qa';
            break;
        case 'production':
            restUrl = 'https://uzirdisrmf.execute-api.us-west-2.amazonaws.com/prod';
            break;
        default:
            restUrl = 'https://uzirdisrmf.execute-api.us-west-2.amazonaws.com/prod';
            break;
    }
    return restUrl;
}
exports.getRestURL = getRestURL;
const getRemoteDeploymentURL = () => {
    let remoteDeploymentUrl = '';
    switch ((0, system_id_1.getSystemId)()) {
        case 'local':
        case 'development':
            remoteDeploymentUrl = 'https://d2hamqrgv8.execute-api.us-west-2.amazonaws.com/dev';
            break;
        case 'qa':
            remoteDeploymentUrl = 'https://o5c3hg01t6.execute-api.us-west-2.amazonaws.com/qa';
            break;
        case 'production':
            remoteDeploymentUrl = 'https://wnsrjz93ce.execute-api.us-west-2.amazonaws.com/prod';
            break;
        default:
            throw new alwayscli_1.CliTerseError(`Remote deployment not supported on ${(0, system_id_1.getSystemId)()}!`);
    }
    return remoteDeploymentUrl;
};
exports.getRemoteDeploymentURL = getRemoteDeploymentURL;
const getBaseURL = () => {
    let baseUrl = '';
    switch ((0, system_id_1.getSystemId)()) {
        case 'local':
            baseUrl = 'http://localhost:3000';
        case 'development':
            baseUrl = 'https://dashboard.a6i0.net';
            break;
        case 'qa':
            baseUrl = 'https://dashboard.a6i1.net';
            break;
        case 'production':
            baseUrl = 'https://www.alwaysai.co';
            break;
        default:
            baseUrl = 'https://www.alwaysai.co';
            break;
    }
    return baseUrl;
};
exports.getBaseURL = getBaseURL;
const envDomainMap = {
    development: 'a6i0.net',
    qa: 'a6i1.net',
    production: 'alwaysai.co',
};
const serviceEndpointBuilder = (service, path) => {
    const domain = envDomainMap[(0, system_id_1.getSystemId)()] || envDomainMap['production'];
    return `https://${service}.${domain}/${path}`;
};
exports.serviceEndpointBuilder = serviceEndpointBuilder;
//# sourceMappingURL=urls.js.map