"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.appInstallCliLeaf = void 0;
const alwayscli_1 = require("@alwaysai/alwayscli");
const cli_inputs_1 = require("../../cli-inputs");
const app_1 = require("../../components/app");
const app_2 = require("../../core/app");
const environment_1 = require("../../environment");
exports.appInstallCliLeaf = (0, alwayscli_1.CliLeaf)({
    name: 'install',
    description: 'Install this application and its dependencies locally or on a remote device',
    namedInputs: {
        yes: cli_inputs_1.yesCliInput,
        clean: cli_inputs_1.cleanCliInput,
        pull: (0, alwayscli_1.CliFlagInput)({ description: 'Pull the base docker image prior to building' }),
        source: (0, alwayscli_1.CliFlagInput)({ description: 'Specifically install the application source' }),
        'skip-models': (0, alwayscli_1.CliFlagInput)({
            description: "Skip the install of the application's models.",
        }),
        targetHardwareOverride: (0, alwayscli_1.CliOneOfInput)({
            values: app_2.TARGET_HARDWARE_OPTIONS,
            hidden: !environment_1.ALWAYSAI_SHOW_HIDDEN,
        }),
    },
    async action(_, opts) {
        const { yes, clean, pull, source, targetHardwareOverride } = opts;
        if (targetHardwareOverride) {
            throw new alwayscli_1.CliTerseError('--targetHardwareOverride has been removed! To package an app for a different architecture please run `aai app configure --hardware <hardware>` and then run `install` and `package`');
        }
        await (0, app_1.appInstallComponent)({
            yes,
            clean,
            pull,
            source,
            skipModels: opts['skip-models'],
        });
    },
});
//# sourceMappingURL=install.js.map