"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const list_1 = require("./list");
const user_1 = require("../../components/user");
const infrastructure_1 = require("../../infrastructure");
const util_1 = require("../../util");
// Mock the dependencies used by deviceList function
jest.mock('../../components/user', () => ({
    checkUserIsLoggedInComponent: jest.fn(),
}));
// Mock the getUserDevices function with different return values for different tests
const mockGetUserDevices = jest.fn();
jest.mock('../../infrastructure', () => ({
    CliAuthenticationClient: jest.fn(() => ({
        getInfo: jest.fn().mockResolvedValue({ username: 'testuser' }),
    })),
    CliRpcClient: jest.fn(() => ({
        getUserDevices: mockGetUserDevices,
    })),
}));
jest.mock('../../util/echo', () => ({
    echo: jest.fn(),
}));
describe('deviceList', () => {
    beforeEach(() => {
        jest.clearAllMocks();
    });
    it('should call the required functions and echo the device table', async () => {
        // Arrange
        // --------------------------------------------------------------------
        const expectedDeviceTable = {
            device_id_1: {
                name: 'Device 1',
                description: 'Test device 1',
                address: 'device-1-host',
            },
            device_id_2: {
                name: 'Device 2',
                description: 'Test device 2',
                address: 'device-2-host',
            },
        };
        // Set the return value for this test
        mockGetUserDevices.mockResolvedValueOnce([
            {
                uuid: 'device_id_1',
                friendly_name: 'Device 1',
                description: 'Test device 1',
                host_name: 'device-1-host',
            },
            {
                uuid: 'device_id_2',
                friendly_name: 'Device 2',
                description: 'Test device 2',
                host_name: 'device-2-host',
            },
        ]);
        // Act
        // --------------------------------------------------------------------
        await list_1.deviceList.action(undefined, { yes: true }, undefined);
        // Assert
        // --------------------------------------------------------------------
        expect(user_1.checkUserIsLoggedInComponent).toHaveBeenCalledWith({ yes: true });
        expect(infrastructure_1.CliAuthenticationClient).toHaveBeenCalledTimes(1);
        expect(mockGetUserDevices).toHaveBeenCalledTimes(1);
        expect(util_1.echo).toHaveBeenCalledWith(JSON.stringify(expectedDeviceTable, null, 2));
    });
    it('should echo an empty device table when no devices are available', async () => {
        // Assert
        // --------------------------------------------------------------------
        mockGetUserDevices.mockResolvedValueOnce([]);
        // Act
        // --------------------------------------------------------------------
        await list_1.deviceList.action(undefined, { yes: true }, undefined);
        // Assert
        // --------------------------------------------------------------------
        expect(user_1.checkUserIsLoggedInComponent).toHaveBeenCalledWith({ yes: true });
        expect(infrastructure_1.CliAuthenticationClient).toHaveBeenCalledTimes(1);
        expect(mockGetUserDevices).toHaveBeenCalledTimes(1);
        expect(util_1.echo).toHaveBeenCalledWith(JSON.stringify({}, null, 2));
    });
});
//# sourceMappingURL=list.test.js.map