"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const prune_1 = require("./prune");
const alwayscli_1 = require("@alwaysai/alwayscli");
const fs = require("fs");
const rimraf = require("rimraf");
const model_1 = require("../../core/model");
jest.mock('rimraf');
const mockRimraf = jest.mocked(rimraf, true);
jest.mock('../../core/model');
jest.mocked(model_1.ModelPackageDirectory).mockReturnValue('/path/to/model/pkgs');
describe(__filename, () => {
    it("throws error if id doesn't exist in cache", () => {
        jest.spyOn(fs, 'existsSync').mockReturnValueOnce(false);
        expect(() => prune_1.testSuiteFuncs.errorIfIdNotInCache('', 'modelId')).toThrow(new alwayscli_1.CliUsageError('Model modelId not found in cache'));
    });
    it('throws error if at least one ignore version is not in cache', () => {
        jest.spyOn(fs, 'existsSync').mockReturnValueOnce(true).mockReturnValueOnce(false);
        expect(() => prune_1.testSuiteFuncs.errorIfIgnoredNotInCache(['0.1', '0.2'], 'model/path', 'modelId')).toThrow(new alwayscli_1.CliUsageError('Ignore version 0.2 for model modelId not found in cache.'));
    });
    it('removes all versions in cache if no ignored version args', () => {
        prune_1.testSuiteFuncs.removeCache('model/path', undefined);
        expect(mockRimraf.sync.mock.calls[0][0]).toBe('model/path/*');
        mockRimraf.sync.mockClear();
    });
    it('ignores specified versions in cache and removes all others', () => {
        prune_1.testSuiteFuncs.removeCache('model/path', ['0.1', '0.2', '0.3']);
        const expectedCall = 'model/path/!(0.1|0.2|0.3)*';
        expect(mockRimraf.sync.mock.calls[0][0]).toBe(expectedCall);
    });
});
//# sourceMappingURL=prune.test.js.map