"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.downloadToFile = exports.throwIfNotOk = void 0;
const node_fetch_1 = require("node-fetch");
const util_1 = require("util");
const path_1 = require("path");
const fs_1 = require("fs");
const coded_error_1 = require("@carnesen/coded-error");
const mkdirp = require("mkdirp");
const pump = require("pump");
const rimraf_1 = require("rimraf");
const alwayscli_1 = require("@alwaysai/alwayscli");
const random_string_1 = require("./random-string");
const constants_1 = require("../constants");
async function download(url) {
    const response = await (0, node_fetch_1.default)(url, {
        method: 'GET',
    });
    await throwIfNotOk(response);
    return response.body;
}
async function throwIfNotOk(response) {
    if (!response.ok) {
        const parsed = (await response.json());
        const { message = `Server responded ${response.status} ("${response.statusText}")`, code, } = parsed;
        throw new coded_error_1.CodedError(message, code);
    }
}
exports.throwIfNotOk = throwIfNotOk;
async function writeToFile(path, readable) {
    mkdirp.sync((0, path_1.dirname)(path));
    const tmpFilePath = `${path}.${(0, random_string_1.RandomString)()}.tmp`;
    try {
        await new Promise((resolve, reject) => {
            const writeable = (0, fs_1.createWriteStream)(tmpFilePath);
            pump(readable, writeable, (err) => {
                if (err) {
                    reject(err);
                }
                else {
                    resolve();
                }
            });
        });
        await (0, util_1.promisify)(fs_1.rename)(tmpFilePath, path);
    }
    catch (exception) {
        try {
            await (0, rimraf_1.default)(tmpFilePath);
        }
        finally {
            throw exception;
        }
    }
}
async function downloadToFile(url, writePath) {
    const fileContents = await download(url);
    if (fileContents === null) {
        throw new alwayscli_1.CliTerseError(`Error downloading ${url}. ${constants_1.PLEASE_REPORT_THIS_ERROR_MESSAGE}`);
    }
    await writeToFile(writePath, fileContents);
}
exports.downloadToFile = downloadToFile;
//# sourceMappingURL=download-to-file.js.map