"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const resolve_posix_path_1 = require("./resolve-posix-path");
describe('Test ResolvePosixPath', () => {
    test('Resolve filename with the from directory', () => {
        const resolvePath = (0, resolve_posix_path_1.ResolvePosixPath)('alwaysai/test');
        const path = resolvePath('alwaysai.app.json');
        expect(path).toEqual((0, path_1.join)('alwaysai/test/alwaysai.app.json'));
    });
    test('Resolve abs path and filename', () => {
        const resolvePath = (0, resolve_posix_path_1.ResolvePosixPath)('alwaysai/test');
        const path = resolvePath('/app', 'alwaysai.app.json');
        expect(path).toEqual((0, path_1.join)('/app/alwaysai.app.json'));
    });
    test('Ignore paths after abs path', () => {
        const resolvePath = (0, resolve_posix_path_1.ResolvePosixPath)('alwaysai/test');
        const path = resolvePath('/app2', '/app', 'alwaysai.app.json');
        expect(path).toEqual((0, path_1.join)('/app/alwaysai.app.json'));
    });
    test('Normalize relative path', () => {
        const resolvePath = (0, resolve_posix_path_1.ResolvePosixPath)('alwaysai/test');
        const path = resolvePath('..', 'app', 'alwaysai.app.json');
        expect(path).toEqual((0, path_1.join)('alwaysai/app/alwaysai.app.json'));
    });
    test('Handle to subdir of from', () => {
        const resolvePath = (0, resolve_posix_path_1.ResolvePosixPath)('alwaysai/test');
        const path = resolvePath('alwaysai', 'test', 'alwaysai.app.json');
        expect(path).toEqual((0, path_1.join)('alwaysai/test/alwaysai.app.json'));
    });
    test.skip('Handle to relative to from', () => {
        const resolvePath = (0, resolve_posix_path_1.ResolvePosixPath)('alwaysai/test');
        const path = resolvePath('alwaysai', 'app', 'alwaysai.app.json');
        expect(path).toEqual((0, path_1.join)('alwaysai/app/alwaysai.app.json'));
    });
    test('Empty from', () => {
        const resolvePath = (0, resolve_posix_path_1.ResolvePosixPath)();
        const path = resolvePath('alwaysai', 'test', 'alwaysai.app.json');
        expect(path).toEqual((0, path_1.join)('alwaysai/test/alwaysai.app.json'));
    });
    test('Empty to', () => {
        const resolvePath = (0, resolve_posix_path_1.ResolvePosixPath)('alwaysai/test');
        const path = resolvePath();
        expect(path).toEqual((0, path_1.join)('alwaysai', 'test'));
    });
});
//# sourceMappingURL=resolve-posix-paths.test.js.map