"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const secure_tunnel_ssh_1 = require("./secure-tunnel-ssh");
const paths_1 = require("../paths");
const child_process_1 = require("child_process");
// import { mocked } from 'ts-jest/utils';
const stream_1 = require("stream");
// ----------------------------------------------------------------------------
// Local constants
// ----------------------------------------------------------------------------
// ----------------------------------------------------------------------------
// Mocks for the SecureTunnelInteractiveSsh
// ----------------------------------------------------------------------------
jest.mock('child_process', () => ({
    spawn: jest.fn(),
}));
jest.mock('../paths', () => ({
    PRIVATE_KEY_FILE_PATH: '/unit/test/path/to/private/key',
}));
// ----------------------------------------------------------------------------
// Tests for SecureTunnelInteractiveSsh
// ----------------------------------------------------------------------------
describe('SecureTunnelInteractiveSsh', () => {
    const testUserName = 'testUser';
    const testSshPort = 5042;
    describe('processArgs', () => {
        beforeEach(() => {
            jest.clearAllMocks();
        });
        it('should process arguments correctly', () => {
            const sshInstance = new secure_tunnel_ssh_1.SecureTunnelInteractiveSsh({
                targetHost: `${testUserName}@localhost`,
                sshPort: testSshPort,
            });
            const processedArgs = sshInstance.processArgs([]);
            expect(processedArgs).toEqual([
                '-i',
                paths_1.PRIVATE_KEY_FILE_PATH,
                '-o',
                'StrictHostKeyChecking=no',
                '-t',
                '-p',
                `${testSshPort}`,
                `${testUserName}@localhost`,
            ]);
        });
        it('should process additional arguments correctly', () => {
            const sshInstance = new secure_tunnel_ssh_1.SecureTunnelInteractiveSsh({
                targetHost: `${testUserName}@localhost`,
                sshPort: testSshPort,
            });
            const additionalArgs = ['-just_a_test', '-alwaysai'];
            const processedArgs = sshInstance.processArgs(additionalArgs);
            expect(processedArgs).toEqual([
                '-i',
                paths_1.PRIVATE_KEY_FILE_PATH,
                '-o',
                'StrictHostKeyChecking=no',
                '-t',
                '-p',
                `${testSshPort}`,
                ...additionalArgs,
                `${testUserName}@localhost`,
            ]);
        });
    });
    describe('runInteractiveSshAsync', () => {
        let mockSshSessionOn;
        beforeEach(() => {
            jest.clearAllMocks();
        });
        it('should run the ssh session', async () => {
            const sshInstance = new secure_tunnel_ssh_1.SecureTunnelInteractiveSsh({
                targetHost: `${testUserName}@localhost`,
                sshPort: testSshPort,
            });
            mockSshSessionOn = jest.fn();
            child_process_1.spawn.mockImplementationOnce(() => ({
                on: mockSshSessionOn,
            }));
            const mockChildProcess = {
                on: jest.fn(),
                stdout: new stream_1.PassThrough(),
                stderr: new stream_1.PassThrough(),
            };
            const testSshArgs = ['arg1', 'arg2'];
            const mockSpawn = child_process_1.spawn;
            mockSpawn.mockReturnValueOnce(mockChildProcess);
            sshInstance.runInteractiveSshAsync(testSshArgs);
            expect(child_process_1.spawn).toBeCalledTimes(1);
            expect(child_process_1.spawn).toHaveBeenCalledWith(`ssh ${testSshArgs.join(' ')}`, {
                stdio: [process.stdin, process.stdout, process.stderr],
                shell: true,
            });
            expect(mockSshSessionOn).toHaveBeenCalledTimes(2);
            expect(mockSshSessionOn).toHaveBeenCalledWith('exit', expect.any(Function));
            expect(mockSshSessionOn).toHaveBeenCalledWith('close', expect.any(Function));
        });
    });
});
//# sourceMappingURL=secure-tunnel-ssh.test.js.map