import { CliTerseError } from '@alwaysai/alwayscli';
import { APP_JSON_FILE_NAME } from '../../../paths';
import { AppJsonFile } from '../../../core/app';
import { ProjectJsonFile } from '../../../core/project';
import { getModels } from '../../../core/model';
import { checkConfigFileExistsAndValid } from '../../../util/config-file-exists-and-is-valid';

export async function checkForInvalidModelsComponent() {
  const appJsonFile = AppJsonFile();

  if (!(await checkConfigFileExistsAndValid(appJsonFile))) {
    throw new CliTerseError(
      `Application does not have a valid ${APP_JSON_FILE_NAME} file.`,
    );
  }
  const appJson = appJsonFile.read();
  const {
    project: { id },
  } = ProjectJsonFile().read();
  const models = appJson.models;
  const userModels: string[] = [];
  (await getModels({ yes: true, projectUuid: id })).forEach((modelEntry) => {
    userModels.push(modelEntry['id']);
  });
  const invalidModels: string[] = [];
  for (const model in models) {
    if (!userModels.includes(model)) {
      invalidModels.push(model);
    }
  }
  return invalidModels;
}
