import { CLI_TERSE_ERROR } from '@alwaysai/alwayscli';
import { runAndCatch } from '@carnesen/run-and-catch';
import * as tempy from 'tempy';
import { AppJsonFile } from '../../../core/app';
import { modelPackageCache } from '../../../core/model';
import { CliAuthenticationClient, CliRpcClient } from '../../../infrastructure';
import { RandomString } from '../../../util';
import { appModelsAddComponent } from './app-models-add-component';

const EMPTY_MODEL_ID = 'alwaysai/squeezenet_v1.1';

describe(appModelsAddComponent.name, () => {
  jest.setTimeout(30000);
  const yes = true;
  it.skip('big test of all the features', async () => {
    // Start with no models
    const dir = tempy.directory();
    const appJsonFile = AppJsonFile(dir);
    appJsonFile.write({ models: {}, scripts: { start: '' } });
    const { username } = await CliAuthenticationClient().getInfo();

    // We'll add the "empty" model
    const { version } = await CliRpcClient().getModelVersion({ id: EMPTY_MODEL_ID });

    // Make sure it's not in the cache
    modelPackageCache.remove(EMPTY_MODEL_ID, version);

    // Now add it
    await appModelsAddComponent({ yes, dir, id: EMPTY_MODEL_ID, addToProject: true });

    // Should now be in the json file and cached
    expect(appJsonFile.read().models).toEqual({
      [EMPTY_MODEL_ID]: version,
    });
    expect(modelPackageCache.has(EMPTY_MODEL_ID, version)).toBe(true);

    // Error condition: model not found
    const exception = await runAndCatch(appModelsAddComponent, {
      yes,
      dir,
      id: `${username}/${RandomString()}`,
      addToProject: true,
    });
    expect(exception.code).toBe(CLI_TERSE_ERROR);
    expect(exception.message).toMatch(/model not found/i);
  });
});
