import * as tempy from 'tempy';

import { appModelsUpdateComponent } from './app-models-update-component';
import { CLI_TERSE_ERROR } from '@alwaysai/alwayscli';
import { runAndCatch } from '@carnesen/run-and-catch';
import { RandomString } from '../../../util';
import { AppJsonFile } from '../../../core/app';
import { CliAuthenticationClient, CliRpcClient } from '../../../infrastructure';

describe(appModelsUpdateComponent.name, () => {
  // ToDo (JR): this test times out in some environments, we should identify the actual cause of the failure and correct it.
  jest.setTimeout(30000);
  const yes = true;
  it.skip('big test of all the features', async () => {
    const dir = tempy.directory();
    const appJsonFile = AppJsonFile(dir);
    const { username } = await CliAuthenticationClient().getInfo();

    // Does nothing if there are no models
    appJsonFile.write({ models: {}, scripts: { start: '' } });
    await appModelsUpdateComponent({ yes, dir });
    expect(appJsonFile.read().models).toEqual({});
    const id = 'alwaysai/yolo_v2';
    appJsonFile.write({
      models: {
        [id]: -1,
      },
      scripts: {
        start: '',
      },
    });

    // Updates the version identifier for an existing model
    await appModelsUpdateComponent({ yes, dir });
    const { version } = await CliRpcClient().getModelVersion({ id });
    expect(appJsonFile.read().models![id]).toBe(version);

    // Operation is idempotent
    await appModelsUpdateComponent({ yes, dir });

    // Throws "model not found" if the model id does not exist
    appJsonFile.write({
      models: { [`${username}/${RandomString()}`]: 1 },
      scripts: { start: '' },
    });
    const exception = await runAndCatch(appModelsUpdateComponent, { yes, dir });
    expect(exception.code).toBe(CLI_TERSE_ERROR);
    expect(exception.message).toMatch(/model not found/i);
  });
});
