import { getTargetHardwareUuid } from '../../core/app';
import { refreshDevice, AaiDevice } from '../../infrastructure';
import { CliTerseError } from '@alwaysai/alwayscli';
import { SshSpawner, runWithSpinner } from '../../util';
import {
  DeviceTokens,
  writeOrValidateDeviceCfgFile,
  writeTokens,
} from '../../core/device';
import { REMOTE_AAI_CFG_DIR_LINUX } from '../../paths';

export async function deviceCheckAndUpdateComponent(props: {
  yes: boolean;
  targetHostname: string;
  device: AaiDevice;
}) {
  const { targetHostname, device } = props;
  const spawner = SshSpawner({
    targetHostname,
    targetPath: REMOTE_AAI_CFG_DIR_LINUX,
  });

  await runWithSpinner(
    async () => {
      const hardwareId = await getTargetHardwareUuid(spawner);
      if (hardwareId !== device.hardware_ids) {
        throw new CliTerseError(`Target device does not match the selected device!`);
      }
      try {
        await writeOrValidateDeviceCfgFile({ spawner, deviceUuid: device.uuid });
      } catch (e) {
        throw new CliTerseError(e.message);
      }
    },
    [],
    'Check device configuration',
  );

  if (device.mode === 'development') {
    // Development tokens don't expire, and therefore don't need to be refreshed.
    // Additionally, we don't want to overwrite existing tokens on a provisioned
    // production device.
    await runWithSpinner(
      async () => {
        const { accessToken, refreshToken, idToken } = await refreshDevice(device.uuid);
        const tokens: DeviceTokens = {
          deviceId: device.uuid,
          accessToken,
          refreshToken,
          idToken,
        };
        await writeTokens({ spawner, tokens });
      },
      [],
      'Write tokens to device',
    );
  }
}
