import { ConfigFileSchema, ConfigFileSchemaReturnType } from '@alwaysai/config-nodejs';
import Ajv, { JSONSchemaType } from 'ajv';
import { join } from 'path';
import { SystemId, SYSTEM_IDS } from '../../constants';
import { DEVICE_CONFIG_FILE_NAME, LOCAL_AAI_CFG_DIR } from '../../paths';

export interface DeviceConfig {
  systemId: SystemId;
  deviceUuid: string;
}

export const deviceConfigSchema: JSONSchemaType<DeviceConfig> = {
  type: 'object',
  properties: {
    systemId: {
      type: 'string',
      enum: SYSTEM_IDS,
    },
    deviceUuid: {
      type: 'string',
    },
  },
  required: ['systemId', 'deviceUuid'],
};

const ajv = new Ajv();

export const validateDeviceConfig = ajv.compile(deviceConfigSchema);

export function DeviceConfigFile(): ConfigFileSchemaReturnType<DeviceConfig> {
  const filePath = join(LOCAL_AAI_CFG_DIR, DEVICE_CONFIG_FILE_NAME);
  const configFile = ConfigFileSchema({
    path: filePath,
    validateFunction: validateDeviceConfig,
  });

  return configFile;
}
