import { DEVICE_CONFIG_FILE_NAME } from '../../paths';
import { getSystemId } from '../../infrastructure';
import { Spawner } from '../../util';
import { DeviceConfig, validateDeviceConfig } from './device-json-file';

export async function writeOrValidateDeviceCfgFile(args: {
  spawner: Spawner;
  deviceUuid: string;
}) {
  const { spawner, deviceUuid } = args;

  if (!(await spawner.exists(DEVICE_CONFIG_FILE_NAME))) {
    const contents: DeviceConfig = { systemId: getSystemId(), deviceUuid };
    await spawner.mkdirp();
    await spawner.writeFile(DEVICE_CONFIG_FILE_NAME, JSON.stringify(contents, null, 2));
    return;
  }

  const origContents = await spawner.readFile(DEVICE_CONFIG_FILE_NAME);
  const origParsed = JSON.parse(origContents);
  if (!validateDeviceConfig(origParsed)) {
    throw new Error(
      `Invalid device config contents: ${JSON.stringify(
        validateDeviceConfig.errors,
        null,
        2,
      )}`,
    );
  }
  if (origParsed.deviceUuid !== deviceUuid) {
    throw new Error("Target device doesn't match selected device!");
  }
}
