import { JsSpawner } from '../../util';

async function spawnProcess(exe: string, args: string[]) {
  const spawner = JsSpawner();
  return await spawner.run({ exe, args });
}

function parseImagesStdOutToArray(images: string): string[] {
  return images.trim().split(/\r?\n/);
}

export async function getAllLegacyTrainingImages() {
  const resProd = await spawnProcess('docker', ['images', '-q', 'alwaysai/train']);
  const resQa = await spawnProcess('docker', ['images', '-q', 'alwaysai/train-qa']);
  const resDev = await spawnProcess('docker', ['images', '-q', 'alwaysai/training-dev']);
  const imageIds: string[] = parseImagesStdOutToArray(`${resProd}\n${resQa}\n${resDev}`);
  return imageIds.length === 1 && imageIds[0] === '' ? [] : imageIds;
}

export async function dockerIsInstalledAndRunning() {
  try {
    await spawnProcess('docker', ['container', 'ls']);
    return true;
  } catch {
    return false;
  }
}

export async function removeDockerImages(images: string[]) {
  await spawnProcess('docker', ['rmi', '-f', ...images]);
}
