import * as tempy from 'tempy';
import { runAndCatch } from '@carnesen/run-and-catch';
import { CLI_TERSE_ERROR } from '@alwaysai/alwayscli';
import pump = require('pump');
import { createWriteStream } from 'fs';
import * as tar from 'tar';

import { modelPackageCloudClient } from './model-package-cloud-client';
import { ModelPackageJsonFile } from './model-package-json-file';
import { join, basename } from 'path';
import { MockModel } from './mock-model';

describe('model package cloud client', () => {
  it(`throws ${CLI_TERSE_ERROR} error if directory does not have a model json file`, async () => {
    const tmpDir = tempy.directory();
    const spy = jest.spyOn(process, 'cwd');
    spy.mockReturnValue(tmpDir);
    const exception = await runAndCatch(modelPackageCloudClient.publish, undefined);
    expect(exception.code).toBe(CLI_TERSE_ERROR);
  });

  it.skip(`publish without id and download`, async () => {
    const mockModel = await MockModel();
    expect(mockModel.metadata.description).toBe(mockModel.json.description);
    expect(mockModel.metadata.final).toBe(true);
    expect(mockModel.metadata.failed).toBe(false);

    const modelPackageFilePath = tempy.file();

    const readable = await modelPackageCloudClient.download(
      mockModel.metadata.id,
      mockModel.metadata.version,
    );
    if (readable === null) {
      throw new Error('Null download result');
    }
    await new Promise<void>((resolve, reject) => {
      pump(readable, createWriteStream(modelPackageFilePath), (err) => {
        if (err) {
          reject(err);
        } else {
          resolve();
        }
      });
    });

    const targetDir = tempy.directory();

    // tar automatically detects gzip compression
    await tar.extract({
      file: modelPackageFilePath,
      cwd: targetDir,
      strict: true,
    });

    const downloadedModelJsonFile = ModelPackageJsonFile(
      join(targetDir, basename(mockModel.dir)),
    );
    expect(downloadedModelJsonFile.read().description).toBe(mockModel.json.description);
  }, 100000);
});
