import { CliLeaf, CliFlagInput, CliTerseError, CliOneOfInput } from '@alwaysai/alwayscli';
import { yesCliInput, cleanCliInput } from '../../cli-inputs';
import { appInstallComponent } from '../../components/app';
import { TARGET_HARDWARE_OPTIONS } from '../../core/app';
import { ALWAYSAI_SHOW_HIDDEN } from '../../environment';

export const appInstallCliLeaf = CliLeaf({
  name: 'install',
  description:
    'Install this application and its dependencies locally or on a remote device',
  namedInputs: {
    yes: yesCliInput,
    clean: cleanCliInput,
    pull: CliFlagInput({ description: 'Pull the base docker image prior to building' }),
    source: CliFlagInput({ description: 'Specifically install the application source' }),
    'skip-models': CliFlagInput({
      description: "Skip the install of the application's models.",
    }),
    targetHardwareOverride: CliOneOfInput({
      values: TARGET_HARDWARE_OPTIONS,
      hidden: !ALWAYSAI_SHOW_HIDDEN,
    }),
  },
  async action(_, opts) {
    const { yes, clean, pull, source, targetHardwareOverride } = opts;
    if (targetHardwareOverride) {
      throw new CliTerseError(
        '--targetHardwareOverride has been removed! To package an app for a different architecture please run `aai app configure --hardware <hardware>` and then run `install` and `package`',
      );
    }
    await appInstallComponent({
      yes,
      clean,
      pull,
      source,
      skipModels: opts['skip-models'],
    });
  },
});
