import { CliLeaf, CliStringInput } from '@alwaysai/alwayscli';
import { yesCliInput } from '../../cli-inputs';
import { checkUserIsLoggedInComponent } from '../../components/user';
import { getModels } from '../../core/model';
import { echo } from '../../util';

export const modelList = CliLeaf({
  name: 'list',
  description: 'List models',
  namedInputs: {
    yes: yesCliInput,
    project: CliStringInput({
      description: 'Project ID',
    }),
  },
  async action(_, { yes, project }) {
    await checkUserIsLoggedInComponent({ yes });
    const models = await getModels({ yes, projectUuid: project });
    const modelTable = {};
    for (const model of models) {
      modelTable[model.id] = {
        id: model.id,
        description: model.description,
        version: model.version,
      };
    }
    echo(JSON.stringify(modelTable, null, 2));
  },
});
