import { testSuiteFuncs } from './prune';
import { CliUsageError } from '@alwaysai/alwayscli';
import * as fs from 'fs';
import * as rimraf from 'rimraf';
import { ModelPackageDirectory } from '../../core/model';

jest.mock('rimraf');
const mockRimraf = jest.mocked(rimraf, true);

jest.mock('../../core/model');
jest.mocked(ModelPackageDirectory).mockReturnValue('/path/to/model/pkgs');

describe(__filename, () => {
  it("throws error if id doesn't exist in cache", () => {
    jest.spyOn(fs, 'existsSync').mockReturnValueOnce(false);
    expect(() => testSuiteFuncs.errorIfIdNotInCache('', 'modelId')).toThrow(
      new CliUsageError('Model modelId not found in cache'),
    );
  });

  it('throws error if at least one ignore version is not in cache', () => {
    jest.spyOn(fs, 'existsSync').mockReturnValueOnce(true).mockReturnValueOnce(false);

    expect(() =>
      testSuiteFuncs.errorIfIgnoredNotInCache(['0.1', '0.2'], 'model/path', 'modelId'),
    ).toThrow(
      new CliUsageError('Ignore version 0.2 for model modelId not found in cache.'),
    );
  });

  it('removes all versions in cache if no ignored version args', () => {
    testSuiteFuncs.removeCache('model/path', undefined);

    expect(mockRimraf.sync.mock.calls[0][0]).toBe('model/path/*');
    mockRimraf.sync.mockClear();
  });

  it('ignores specified versions in cache and removes all others', () => {
    testSuiteFuncs.removeCache('model/path', ['0.1', '0.2', '0.3']);

    const expectedCall = 'model/path/!(0.1|0.2|0.3)*';
    expect(mockRimraf.sync.mock.calls[0][0]).toBe(expectedCall);
  });
});
