import { join } from 'path';
import { ResolvePosixPath } from './resolve-posix-path';

describe('Test ResolvePosixPath', () => {
  test('Resolve filename with the from directory', () => {
    const resolvePath = ResolvePosixPath('alwaysai/test');
    const path = resolvePath('alwaysai.app.json');
    expect(path).toEqual(join('alwaysai/test/alwaysai.app.json'));
  });

  test('Resolve abs path and filename', () => {
    const resolvePath = ResolvePosixPath('alwaysai/test');
    const path = resolvePath('/app', 'alwaysai.app.json');
    expect(path).toEqual(join('/app/alwaysai.app.json'));
  });

  test('Ignore paths after abs path', () => {
    const resolvePath = ResolvePosixPath('alwaysai/test');
    const path = resolvePath('/app2', '/app', 'alwaysai.app.json');
    expect(path).toEqual(join('/app/alwaysai.app.json'));
  });

  test('Normalize relative path', () => {
    const resolvePath = ResolvePosixPath('alwaysai/test');
    const path = resolvePath('..', 'app', 'alwaysai.app.json');
    expect(path).toEqual(join('alwaysai/app/alwaysai.app.json'));
  });

  test('Handle to subdir of from', () => {
    const resolvePath = ResolvePosixPath('alwaysai/test');
    const path = resolvePath('alwaysai', 'test', 'alwaysai.app.json');
    expect(path).toEqual(join('alwaysai/test/alwaysai.app.json'));
  });

  test.skip('Handle to relative to from', () => {
    const resolvePath = ResolvePosixPath('alwaysai/test');
    const path = resolvePath('alwaysai', 'app', 'alwaysai.app.json');
    expect(path).toEqual(join('alwaysai/app/alwaysai.app.json'));
  });

  test('Empty from', () => {
    const resolvePath = ResolvePosixPath();
    const path = resolvePath('alwaysai', 'test', 'alwaysai.app.json');
    expect(path).toEqual(join('alwaysai/test/alwaysai.app.json'));
  });

  test('Empty to', () => {
    const resolvePath = ResolvePosixPath('alwaysai/test');
    const path = resolvePath();
    expect(path).toEqual(join('alwaysai', 'test'));
  });
});
